==> kea-docs-1:3.0.1-3-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d6/d55/shared__network_8h.js <==
var shared__network_8h =
[
    [ "isc::dhcp::SharedNetwork4", "d0/db4/classisc_1_1dhcp_1_1SharedNetwork4.html", "d0/db4/classisc_1_1dhcp_1_1SharedNetwork4" ],
    [ "isc::dhcp::SharedNetwork6", "db/df6/classisc_1_1dhcp_1_1SharedNetwork6.html", "db/df6/classisc_1_1dhcp_1_1SharedNetwork6" ],
    [ "isc::dhcp::SharedNetworkFetcher< ReturnPtrType, CollectionType >", "d8/d29/classisc_1_1dhcp_1_1SharedNetworkFetcher.html", null ],
    [ "isc::dhcp::SharedNetworkIdIndexTag", "d2/d34/structisc_1_1dhcp_1_1SharedNetworkIdIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkModificationTimeIndexTag", "d4/d8e/structisc_1_1dhcp_1_1SharedNetworkModificationTimeIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkNameIndexTag", "d7/d23/structisc_1_1dhcp_1_1SharedNetworkNameIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkRandomAccessIndexTag", "d5/d00/structisc_1_1dhcp_1_1SharedNetworkRandomAccessIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkServerIdIndexTag", "d0/d85/structisc_1_1dhcp_1_1SharedNetworkServerIdIndexTag.html", null ],
    [ "isc::dhcp::SharedNetwork4Collection", "d5/d8c/namespaceisc_1_1dhcp.html#ab502ad838ae27ef69ccb1cfbae510d71", null ],
    [ "isc::dhcp::SharedNetwork4Ptr", "d5/d8c/namespaceisc_1_1dhcp.html#ad440983c10e3dbd1ceda5ca29f1780ac", null ],
    [ "isc::dhcp::SharedNetwork6Collection", "d5/d8c/namespaceisc_1_1dhcp.html#a284fee70b8357031947ae6ba092ddb6a", null ],
    [ "isc::dhcp::SharedNetwork6Ptr", "d5/d8c/namespaceisc_1_1dhcp.html#a7fb584e54f0480b9e5525b38d18bcf2e", null ],
    [ "isc::dhcp::SharedNetworkFetcher4", "d5/d8c/namespaceisc_1_1dhcp.html#a226b4ee2ef1471f0e3fc4f4f738314c0", null ],
    [ "isc::dhcp::SharedNetworkFetcher6", "d5/d8c/namespaceisc_1_1dhcp.html#af61b09580d3fda2eb53b15a3a276192b", null ]
];

==> kea-docs-1:3.0.2-2-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d6/d55/shared__network_8h.js <==
var shared__network_8h =
[
    [ "isc::dhcp::SharedNetwork4", "d0/db4/classisc_1_1dhcp_1_1SharedNetwork4.html", "d0/db4/classisc_1_1dhcp_1_1SharedNetwork4" ],
    [ "isc::dhcp::SharedNetwork6", "db/df6/classisc_1_1dhcp_1_1SharedNetwork6.html", "db/df6/classisc_1_1dhcp_1_1SharedNetwork6" ],
    [ "isc::dhcp::SharedNetworkFetcher&lt; ReturnPtrType, CollectionType &gt;", "d8/d29/classisc_1_1dhcp_1_1SharedNetworkFetcher.html", null ],
    [ "isc::dhcp::SharedNetworkIdIndexTag", "d2/d34/structisc_1_1dhcp_1_1SharedNetworkIdIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkModificationTimeIndexTag", "d4/d8e/structisc_1_1dhcp_1_1SharedNetworkModificationTimeIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkNameIndexTag", "d7/d23/structisc_1_1dhcp_1_1SharedNetworkNameIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkRandomAccessIndexTag", "d5/d00/structisc_1_1dhcp_1_1SharedNetworkRandomAccessIndexTag.html", null ],
    [ "isc::dhcp::SharedNetworkServerIdIndexTag", "d0/d85/structisc_1_1dhcp_1_1SharedNetworkServerIdIndexTag.html", null ],
    [ "isc::dhcp::SharedNetwork4Collection", "d5/d8c/namespaceisc_1_1dhcp.html#ab502ad838ae27ef69ccb1cfbae510d71", null ],
    [ "isc::dhcp::SharedNetwork4Ptr", "d5/d8c/namespaceisc_1_1dhcp.html#ad440983c10e3dbd1ceda5ca29f1780ac", null ],
    [ "isc::dhcp::SharedNetwork6Collection", "d5/d8c/namespaceisc_1_1dhcp.html#a284fee70b8357031947ae6ba092ddb6a", null ],
    [ "isc::dhcp::SharedNetwork6Ptr", "d5/d8c/namespaceisc_1_1dhcp.html#a7fb584e54f0480b9e5525b38d18bcf2e", null ],
    [ "isc::dhcp::SharedNetworkFetcher4", "d5/d8c/namespaceisc_1_1dhcp.html#a226b4ee2ef1471f0e3fc4f4f738314c0", null ],
    [ "isc::dhcp::SharedNetworkFetcher6", "d5/d8c/namespaceisc_1_1dhcp.html#af61b09580d3fda2eb53b15a3a276192b", null ]
];
